==> image-editor_1.0.11.orig.tar.xz: image-editor-1.0.11/libimageviewer/translations/libimageviewer_ne.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ne" version="2.1">
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation>छवि जानकारी</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LibImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation>आधारभूत जानकारी</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>विवरण</translation>
    </message>
</context>
<context>
    <name>LibViewPanel</name>
    <message>
        <source>Add to album</source>
        <translation>एल्बममा थप्नुहोस्</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>नयाँ एल्बम</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>सबै छविहरू</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>छवि खोल्नुहोस्</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>एल्बमबाट हटाउनुहोस्</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>मन नपर्ने</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>मनपर्ने</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>तपाईंसँग तस्वीर हेर्न अनुमति छैन</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>नाम</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>प्रकार</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>मिति परिमार्जित</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>फाईल आकार</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>मिति कब्जा गरियो</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>एक्सपोजर मोड</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>एक्सपोजर प्रोग्राम</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>एक्सपोजर समय</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>फ्ल्यास</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>एपर्चर</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>फोकल लम्बाई</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>अधिकतम एपर्चर</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>मिटरिंग मोड</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>सेतो सन्तुलन</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>फ्ल्यास क्षतिपूर्ति</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>लेन्स मोडेल</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>कलरस्पेस</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>क्यामेरा मोडेल</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>आयाम</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>ट्याग</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Back</source>
        <translation>पछाडि</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>अघिल्लो</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>अर्को</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>1: 1 आकार</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>विन्डोमा फिट</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>घडिको उल्टो दिशामा घुमाउनुहोस्</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>घडीको दिशामा घुमाउनुहोस्</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>हटाउनु होस् </translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>पूर्णस्क्रीनबाट बाहिर निस्कनुहोस्</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>पूर्णस्क्रीन</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>प्रिन्ट गर्नुहोस्</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>स्लाइड शो</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>कपि </translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>नाम बदल्नुहोस्</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>नेभिगेसन विन्डो देखाउनुहोस्</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>नेभिगेसन विन्डो लुकाउनुहोस्</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>वालपेपरको रूपमा सेट गर्नुहोस्</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>फाइल प्रबन्धकमा प्रदर्शन गर्नुहोस्</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>छवि जानकारी</translation>
    </message>
    <message>
        <source>day</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation>रद्द गर्नुहोस्</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>अघिल्लो</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Play</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Next</source>
        <translation>अर्को</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>कुनै छवि फाईलहरू फेला परेनन्</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>छवि फाईल फेला परेन</translation>
    </message>
    <message>
        <source>You have no permission to view the file</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> image-editor_1.0.21.orig.tar.xz: image-editor-1.0.21/libimageviewer/translations/libimageviewer_ne.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ne">
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation>छवि जानकारी</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LibImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation>आधारभूत जानकारी</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>विवरण</translation>
    </message>
</context>
<context>
    <name>LibViewPanel</name>
    <message>
        <source>Add to album</source>
        <translation>एल्बममा थप्नुहोस्</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>नयाँ एल्बम</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>सबै छविहरू</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>छवि खोल्नुहोस्</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>एल्बमबाट हटाउनुहोस्</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>मन नपर्ने</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>मनपर्ने</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>तपाईंसँग तस्वीर हेर्न अनुमति छैन</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>नाम</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>प्रकार</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>मिति परिमार्जित</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>फाईल आकार</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>मिति कब्जा गरियो</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>एक्सपोजर मोड</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>एक्सपोजर प्रोग्राम</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>एक्सपोजर समय</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>फ्ल्यास</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>एपर्चर</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>फोकल लम्बाई</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>अधिकतम एपर्चर</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>मिटरिंग मोड</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>सेतो सन्तुलन</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>फ्ल्यास क्षतिपूर्ति</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>लेन्स मोडेल</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>कलरस्पेस</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>क्यामेरा मोडेल</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>आयाम</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>ट्याग</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Back</source>
        <translation>पछाडि</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>अघिल्लो</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>अर्को</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>1: 1 आकार</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>विन्डोमा फिट</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>घडिको उल्टो दिशामा घुमाउनुहोस्</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>घडीको दिशामा घुमाउनुहोस्</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>हटाउनु होस् </translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>पूर्णस्क्रीनबाट बाहिर निस्कनुहोस्</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>पूर्णस्क्रीन</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>प्रिन्ट गर्नुहोस्</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>स्लाइड शो</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>कपि </translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>नाम बदल्नुहोस्</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>नेभिगेसन विन्डो देखाउनुहोस्</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>नेभिगेसन विन्डो लुकाउनुहोस्</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>वालपेपरको रूपमा सेट गर्नुहोस्</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>फाइल प्रबन्धकमा प्रदर्शन गर्नुहोस्</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>छवि जानकारी</translation>
    </message>
    <message>
        <source>day</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>रद्द गर्नुहोस्</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The file already exists, please use another name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>अघिल्लो</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Next</source>
        <translation>अर्को</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>कुनै छवि फाईलहरू फेला परेनन्</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>छवि फाईल फेला परेन</translation>
    </message>
    <message>
        <source>You have no permission to view the file</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
